@@ -13,8 +13,8 @@ icon_config = {
         "library": "zondicons",
     },
     "icon_size": "400%",
-    "icon_foreground": "",
-    "icon_rounded": False,
+    "icon_foreground": "primary",
+    "icon_rounded": True,
     "attributes": {"color": "black"},
     "background_context": "primary",
     "background_opacity": "50",
